==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/bg.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "записва...",
    "saved!" : "записан!",
    "failed!" : "неуспешно!",
    "Saved" : "Запазено",
    "There was a problem saving your changes. Click to resume editing." : "Възникна проблем при записване на промените. Кликнете, за да се възобнови редактирането.",
    "An error occurred!" : "Възникна грешка!",
    "Edit" : "Редакция",
    "Mixed" : "Комбинирано",
    "Preview" : "Преглед",
    "New text file" : "Нов текстов файл",
    "New text file.txt" : "Нов текст file.txt",
    "You can not open a folder" : "Не можете да отворите папката",
    "This file is too big to be opened. Please download the file instead." : "Този файл е твърде голям, за да се отвори. Моля, изтеглете файла.",
    "Cannot read the file." : "файлът неможе да бъде прочетен.",
    "Invalid file path supplied." : "Предоставен е невалиден път до файл.",
    "The file is locked." : "Файлът е заключен.",
    "An internal server error occurred." : "Възникна вътрешна грешка на сървъра.",
    "You can not write to a folder" : "Не можете да записвате в папката",
    "Cannot save file as it has been modified since opening" : "Файлът не може да бъде запаметен, защото е бил модифициран след отварянето му",
    "Insufficient permissions" : "Недостатъчни права",
    "File path not supplied" : "Не е предоставен път до файл",
    "File mtime not supplied" : "Не е предоставено време на модификация на файла - mtime",
    "Text editor" : "Текстов редактор"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/bg.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "записва...",
    "saved!" : "записан!",
    "failed!" : "неуспешно!",
    "Saved" : "Запазено",
    "There was a problem saving your changes. Click to resume editing." : "Възникна проблем при записване на промените. Кликнете, за да се възобнови редактирането.",
    "An error occurred!" : "Възникна грешка!",
    "Edit" : "Редакция",
    "Mixed" : "Комбинирано",
    "Preview" : "Преглед",
    "New text file" : "Нов текстов файл",
    "New text file.txt" : "Текстов файл.txt",
    "You can not open a folder" : "Не можете да отворите папката",
    "This file is too big to be opened. Please download the file instead." : "Този файл е твърде голям, за да се отвори. Моля, изтеглете файла.",
    "Cannot read the file." : "файлът неможе да бъде прочетен.",
    "Invalid file path supplied." : "Предоставен е невалиден път до файл.",
    "The file is locked." : "Файлът е заключен.",
    "An internal server error occurred." : "Възникна вътрешно сървърна грешка.",
    "You can not write to a folder" : "Не можете да записвате в папката",
    "Cannot save file as it has been modified since opening" : "Файлът не може да бъде запаметен, защото е бил модифициран след отварянето му",
    "Insufficient permissions" : "Недостатъчни права",
    "File path not supplied" : "Не е предоставен път до файл",
    "File mtime not supplied" : "Не е предоставено време на модификация на файла - mtime",
    "Text editor" : "Текстов редактор"
},
"nplurals=2; plural=(n != 1);");
